@@ -30,7 +30,7 @@ function(model,data,...) {
     
     fit <- try(sem(model,data[-i,],...),TRUE)
     
-    if (class(fit)=="try-error") {
+    if (inherits(fit,"try-error")) {
       NA
     } else {
       if ((length(var.idx)>0L && any(fit@Fit@est[var.idx]<0))|(!fit@Fit@converged)) {
